@@ -22,20 +22,17 @@ extern "C" {
  *  weil nichts zu zeichnen ist
  */
 
-extern short DtClipLine(
-	double xmin, double ymin,	/* Linke untere Ecke des Clip-Bereichs */
-	double xmax, double ymax,	/* Rechte obere Ecke des Clip-Bereichs */
-	double *x1, double *y1,		/* Pointer auf Startpunkt der Linie */
-	double *x2, double *y2);	/* Pointer auf Endpunkt der Linie */
+	extern short DtClipLine(double xmin, double ymin,	/* Linke untere Ecke des Clip-Bereichs */
+				double xmax, double ymax,	/* Rechte obere Ecke des Clip-Bereichs */
+				double *x1, double *y1,	/* Pointer auf Startpunkt der Linie */
+				double *x2, double *y2);	/* Pointer auf Endpunkt der Linie */
 
-extern short DtClipFilledBox(
-	double xmin, double ymin,	/* Linke untere Ecke des Clip-Bereichs */
-	double xmax, double ymax,	/* Rechte obere Ecke des Clip-Bereichs */
-	double *x1, double *y1,		/* Pointer auf Startpunkt der Box */
-	double *x2, double *y2);	/* Pointer auf Endpunkt der Box */
+	extern short DtClipFilledBox(double xmin, double ymin,	/* Linke untere Ecke des Clip-Bereichs */
+				     double xmax, double ymax,	/* Rechte obere Ecke des Clip-Bereichs */
+				     double *x1, double *y1,	/* Pointer auf Startpunkt der Box */
+				     double *x2, double *y2);	/* Pointer auf Endpunkt der Box */
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
