@@ -4,7 +4,7 @@
 #include "hp2xx.h"
 
 int read_float (float *pnum, FILE * hd);
-
+void read_string (char *target, FILE *);
 void PlotCmd_to_tmpfile (PlotCmd cmd);
 
 void HPGL_Pt_to_tmpfile (const HPGL_Pt * pf);
@@ -15,7 +15,7 @@ void HPGL_Pt_to_polygon (const HPGL_Pt pf );
 void reset_tmpfile(void);
 #endif
 
-#ifdef __TURBOC__
+#if defined __TURBOC__ || defined __STRICT_ANSI__
 #define	HYPOT(x,y)	sqrt((x)*(x)+(y)*(y))
 #else
 #define	HYPOT(x,y)	hypot(x,y)
