@@ -81,8 +81,8 @@ static void swapout_RowBuf(RowBuf * row, const PicBuf * picbuf)
 	}
 
 	if ((int)
-	    fwrite((char *) row->buf, picbuf->nb, picbuf->depth,
-		   picbuf->sd)
+	    fwrite((char *) row->buf, (size_t) picbuf->nb,
+		   (size_t) picbuf->depth, picbuf->sd)
 	    != picbuf->depth) {
 		PError("swapout_RowBuf (on write)");
 		exit(ERROR);
@@ -101,7 +101,8 @@ static void swapin_RowBuf(RowBuf * row, const PicBuf * picbuf)
 	}
 
 	if ((int)
-	    fread((char *) row->buf, picbuf->nb, picbuf->depth, picbuf->sd)
+	    fread((char *) row->buf, (size_t) picbuf->nb,
+		  (size_t) picbuf->depth, picbuf->sd)
 	    != picbuf->depth) {
 		PError("swapin_RowBuf (on read)");
 		exit(ERROR);
@@ -194,7 +195,8 @@ RowBuf *get_RowBuf(const PicBuf * pb, int index)
 
 
 
-static void plot_RowBuf(RowBuf * rowbuf, int x, int depth, int color_index)
+static void plot_RowBuf(RowBuf * rowbuf, int x, int depth,
+			PEN_C color_index)
 /**
  ** Write color index into pixel x of given row buffer
  **/
@@ -239,7 +241,7 @@ static void plot_RowBuf(RowBuf * rowbuf, int x, int depth, int color_index)
 		*addr &= ~Mask;
 		*addr |= color_index;
 	} else
-		*addr = color_index;
+		*addr = (Byte) color_index;
 }
 
 
@@ -447,8 +449,9 @@ PicBuf *allocate_PicBuf(const GEN_PAR * pg, int n_rows, int n_cols)
 
 		for (nr = 0; nr < pb->nr; nr++)
 			if ((int)
-			    fwrite((char *) pb->row[0].buf, pb->nb,
-				   pb->depth, pb->sd)
+			    fwrite((char *) pb->row[0].buf,
+				   (size_t) pb->nb, (size_t) pb->depth,
+				   pb->sd)
 			    != pb->depth) {
 				Eprintf("Couldn't clear swap file!\n");
 				PError("hp2xx");
@@ -497,7 +500,7 @@ void free_PicBuf(PicBuf * pb)
 
 
 
-void plot_PicBuf(PicBuf * pb, DevPt * pt, int color_index)
+void plot_PicBuf(PicBuf * pb, DevPt * pt, PEN_C color_index)
 {
 	if ((pt->x + X_Offset) < 0 || pt->x > (pb->nc - X_Offset)) {
 		Eprintf("plot_PicBuf: Illegal x (%d not in [0, %d])\n",
@@ -523,7 +526,8 @@ int index_from_PicBuf(const PicBuf * pb, const DevPt * pt)
 }
 
 
-static void dot_PicBuf(DevPt * p0, int pensize, int pencolor, PicBuf * pb)
+static void dot_PicBuf(DevPt * p0, int pensize, PEN_C pencolor,
+		       PicBuf * pb)
 {
 
 	DevPt pt;
@@ -560,7 +564,7 @@ static void dot_PicBuf(DevPt * p0, int pensize, int pencolor, PicBuf * pb)
 
 
 static void
-line_PicBuf(DevPt * p0, DevPt * p1, PEN_W pensize, int pencolor,
+line_PicBuf(DevPt * p0, DevPt * p1, PEN_W pensize, PEN_C pencolor,
 	    int consecutive, const OUT_PAR * po)
     /**
      ** Rasterize a vector (draw a line in the picture buffer), using the
@@ -572,7 +576,7 @@ line_PicBuf(DevPt * p0, DevPt * p1, PEN_W pensize, int pencolor,
 	DevPt t0, t1, t2, t3;
 	double len, xoff, yoff;
 	int dx, dy;
-	int linewidth = ceil(pensize * po->HP_to_xdots / 0.025);	/* convert to pixel space */
+	int linewidth = (int) ceil(pensize * po->HP_to_xdots / 0.025);	/* convert to pixel space */
 
 /*   printf("pensize = %0.3f mm, linewidth = %d pixels\n",pensize,linewidth);*/
 
@@ -582,6 +586,9 @@ line_PicBuf(DevPt * p0, DevPt * p1, PEN_W pensize, int pencolor,
 	if (pencolor == xxBackground)	/* No drawable color!       */
 		return;
 
+	if (linewidth < 5)
+		consecutive = 0;
+
 	if (linewidth == 1) {	/* Thin lines of any attitude */
 		p_act = bresenham_init(p0, p1);
 		do {
@@ -665,7 +672,7 @@ line_PicBuf(DevPt * p0, DevPt * p1, PEN_W pensize, int pencolor,
 
 }
 
-void polygon_PicBuf(DevPt p4, DevPt p2, DevPt p1, DevPt p3, int pencolor,
+void polygon_PicBuf(DevPt p4, DevPt p2, DevPt p1, DevPt p3, PEN_C pencolor,
 		    PicBuf * pb)
 {
 
@@ -676,7 +683,7 @@ void polygon_PicBuf(DevPt p4, DevPt p2, DevPt p1, DevPt p3, int pencolor,
 	double denominator;
 	double A1, B1, C1, A2, B2, C2;
 	int scany;
-	int segx, segy, numlines;
+	int segx, numlines;
 	int i, j, k;
 /*
 fprintf (stderr,"in polydraw: (%d,%d) (%d,%d) (%d,%d) (%d,%d)\n",p1.x,p1.y,p2.x,p2.y,p3.x,p3.y,
@@ -731,8 +738,8 @@ continue;
 */
 /* coefficients for current scan line */
 		A1 = 0.;
-		B1 = xmin - xmax;
-		C1 = scany * (xmax - xmin);
+		B1 = (double) (xmin - xmax);
+		C1 = (double) (scany * (xmax - xmin));
 
 		for (j = 0; j <= 6; j = j + 2) {	/*for all polygon edges */
 			if ((scany < MIN(polygon[j].y, polygon[j + 1].y))
@@ -741,19 +748,18 @@ continue;
 				continue;
 
 /* coefficients for this edge */
-			A2 = polygon[j + 1].y - polygon[j].y;
-			B2 = polygon[j].x - polygon[j + 1].x;
-			C2 = polygon[j].x * (polygon[j].y -
-					     polygon[j + 1].y) +
-			    polygon[j].y * (polygon[j + 1].x -
-					    polygon[j].x);
+			A2 = (double) (polygon[j + 1].y - polygon[j].y);
+			B2 = (double) (polygon[j].x - polygon[j + 1].x);
+			C2 = (double) (polygon[j].x *
+				       (polygon[j].y - polygon[j + 1].y) +
+				       polygon[j].y * (polygon[j + 1].x -
+						       polygon[j].x));
 
 /*determine coordinates of intersection */
 			denominator = A1 * B2 - A2 * B1;
 			if (fabs(denominator) > 1.e-5) {	/* zero means parallel lines */
 
 				segx = (int) ((B1 * C2 - B2 * C1) / denominator);	/*x coordinate of intersection */
-				segy = (C1 * A2 - C2 * A1) / denominator;	/*y coordinate of intersection */
 
 /*fprintf(stderr,"seg x,y= %d %d\n",segx,segy);*/
 				if ((segx > xmax) || (segx < xmin) ||
@@ -784,11 +790,9 @@ continue;
 				start = tmp;
 			}
 /*fprintf(stderr,"fillline %d %d - %d %d\n",start.x,start.y,end.x,end.y);*/
-#if 1
 			for (p_act.x = start, p_act.y = scany;
 			     p_act.x <= end; p_act.x++)
 				plot_PicBuf(pb, &p_act, pencolor);
-#endif
 		}
 	}			/* next scanline */
 
@@ -803,7 +807,7 @@ void tmpfile_to_PicBuf(const GEN_PAR * pg, const OUT_PAR * po)
  **/
 {
 	HPGL_Pt pt1;
-	static DevPt ref = { 0 };
+	static DevPt ref = { 0, 0 };
 	DevPt next;
 	PlotCmd cmd;
 	static int consecutive = 0;
