@@ -67,14 +67,14 @@ static PEN_W lastwidth;
 static int lastcap;
 static int lastjoin;
 static int lastlimit;
-static int lastred, lastgreen, lastblue;
+static BYTE lastred, lastgreen, lastblue;
 
 void ps_set_linewidth(PEN_W, HPGL_Pt *, FILE *);
 void ps_set_linecap(LineEnds type, PEN_W pensize, HPGL_Pt * ppt,
 		    FILE * fd);
 void ps_set_linejoin(LineJoins type, LineLimit limit, PEN_W pensize,
 		     HPGL_Pt * ppt, FILE * fd);
-void ps_set_color(int pencolor, HPGL_Pt * ppt, FILE * fd);
+void ps_set_color(PEN_C pencolor, HPGL_Pt * ppt, FILE * fd);
 void ps_init(const GEN_PAR *, const OUT_PAR *, FILE *, PEN_W);
 void ps_end(FILE *);
 void ps_stroke_and_move_to(HPGL_Pt *, FILE *);
@@ -173,7 +173,7 @@ void ps_set_linejoin(LineJoins type, LineLimit limit, PEN_W pensize,
 		switch (type) {
 		case LAJ_plain_miter:
 			newjoin = 0;
-			newlimit = 100;	/* arbitrary value */
+			newlimit = 5;	/* arbitrary value */
 			break;
 		case LAJ_bevel_miter:	/* not available */
 			newjoin = 0;
@@ -193,7 +193,7 @@ void ps_set_linejoin(LineJoins type, LineLimit limit, PEN_W pensize,
 			break;
 		default:
 			newjoin = 0;
-			newlimit = 100;	/* arbitrary value */
+			newlimit = 5;	/* arbitrary value */
 			break;
 		}
 	} else {
@@ -218,7 +218,7 @@ void ps_set_linejoin(LineJoins type, LineLimit limit, PEN_W pensize,
 /**
  ** Set RGB color
  **/
-void ps_set_color(int pencolor, HPGL_Pt * ppt, FILE * fd)
+void ps_set_color(PEN_C pencolor, HPGL_Pt * ppt, FILE * fd)
 {
 	if ((pt.clut[pencolor][0] != lastred) ||
 	    (pt.clut[pencolor][1] != lastgreen)
@@ -273,8 +273,9 @@ char *Getdate(void)
 
 	t = time((time_t *) 0);
 	p = ctime(&t);
-	len = strlen(p);
-	*(p + len - 1) = '\0';	/* zap the newline character */
+	len = (int) strlen(p);
+							/*@-modobserver@ */ *(p + len - 1) = '\0';
+							/* zap the newline character */
 	return p;
 }
 
@@ -303,7 +304,7 @@ void ps_init(const GEN_PAR * pg, const OUT_PAR * po, FILE * fd,
 	fprintf(fd, "%%!PS-Adobe-2.0 EPSF-2.0\n");
 	fprintf(fd, "%%%%Title: %s\n", po->outfile);
 	fprintf(fd,
-		"%%%%Creator: hp2xx (c) 1991 - 1994 by  H. Werntges\n");
+		"%%%%Creator: hp2xx %s (c) 1991-1994 by H. Werntges, 1999-2003 by M. Kroeker\n",VERS_NO);
 	fprintf(fd, "%%%%CreationDate: %s\n", Getdate());
 	fprintf(fd, "%%%%Pages: 1\n");
 
@@ -312,8 +313,8 @@ void ps_init(const GEN_PAR * pg, const OUT_PAR * po, FILE * fd,
  **
  ** (hmxpenw & floor/ceil corrections suggested by Eric Norum)
  **/
-	left = (long) floor(abs(po->xoff - hmxpenw) * MM_TO_PS_POINT);
-	low = (long) floor(abs(po->yoff - hmxpenw) * MM_TO_PS_POINT);
+	left = (long) floor(fabs(po->xoff - hmxpenw) * MM_TO_PS_POINT);
+	low = (long) floor(fabs(po->yoff - hmxpenw) * MM_TO_PS_POINT);
 	right =
 	    (long) ceil((po->xoff + po->width + hmxpenw) * MM_TO_PS_POINT);
 	high =
