@@ -56,8 +56,8 @@ int PicBuf_to_JPG(const GEN_PAR * pg, const OUT_PAR * po)
 
 	cinfo.err = jpeg_std_error(&jerr);
 	jpeg_create_compress(&cinfo);
-	cinfo.image_width = H;	/* image width and height, in pixels */
-	cinfo.image_height = W;
+	cinfo.image_width = (JDIMENSION) H;	/* image width and height, in pixels */
+	cinfo.image_height = (JDIMENSION) W;
 	if (D == 1) {
 		cinfo.input_components = 1;
 		cinfo.in_color_space = JCS_GRAYSCALE;
@@ -77,44 +77,6 @@ int PicBuf_to_JPG(const GEN_PAR * pg, const OUT_PAR * po)
 		jpeg_stdio_dest(&cinfo, stdout);
 	}
 
-#if 0
-	switch (po->specials) {
-	case 0:		/* no compression */
-	case 1:
-		TIFFSetField(w, TIFFTAG_COMPRESSION, COMPRESSION_NONE);
-		break;
-	case 2:		/* Run Length Encoding */
-		TIFFSetField(w, TIFFTAG_COMPRESSION, COMPRESSION_CCITTRLE);
-		D = 1;
-		break;
-	case 3:		/* Group 3 Fax monochrome */
-		TIFFSetField(w, TIFFTAG_COMPRESSION,
-			     COMPRESSION_CCITTFAX3);
-		D = 1;
-		break;
-	case 4:		/* Group 4 Fax monochrome */
-		TIFFSetField(w, TIFFTAG_COMPRESSION,
-			     COMPRESSION_CCITTFAX4);
-		D = 1;
-		break;
-	case 5:		/* LZW is patented by Unisys - only license holders should use next line */
-		/*  TIFFSetField(w, TIFFTAG_COMPRESSION, COMPRESSION_LZW); */
-		break;
-	case 6:		/* JPEG formats */
-		TIFFSetField(w, TIFFTAG_COMPRESSION, COMPRESSION_OJPEG);
-		break;
-	case 7:
-		TIFFSetField(w, TIFFTAG_COMPRESSION, COMPRESSION_JPEG);
-		break;
-	case 8:
-		TIFFSetField(w, TIFFTAG_COMPRESSION, COMPRESSION_DEFLATE);
-		break;
-	default:
-		Eprintf("\nCompression Format - not supported yet\n");
-		break;
-	}
-#endif
-
 	S = 3 * po->picbuf->nc;
 	if (D == 1)
 		S = po->picbuf->nc;
@@ -131,10 +93,11 @@ int PicBuf_to_JPG(const GEN_PAR * pg, const OUT_PAR * po)
 	for (y = 0; y < W; ++y) {
 		if ((row = get_RowBuf(po->picbuf, (W - 1) - y)) == NULL)
 			break;
-		memset(jpgbuf, 0, S);
+		memset(jpgbuf, 0, (size_t) S);
 		i = 0;
 		for (x = 0; x < H; ++x) {
-			Byte C = index_from_RowBuf(row, x, po->picbuf);
+			Byte C =
+			    (Byte) index_from_RowBuf(row, x, po->picbuf);
 			if (D == 1) {
 				switch (C) {
 				case xxBackground:
@@ -151,7 +114,7 @@ int PicBuf_to_JPG(const GEN_PAR * pg, const OUT_PAR * po)
 			}
 		}
 		row_pointer[0] = &jpgbuf[0];
-		jpeg_write_scanlines(&cinfo, row_pointer, 1);
+		(void) jpeg_write_scanlines(&cinfo, row_pointer, 1);
 	}
 
 	free(jpgbuf);
