@@ -91,7 +91,8 @@ static void RLEcode_to_file(int c, int repeat, FILE * fd)
 
 static void byte_to_PCX(Byte b, PCXmode mode, FILE * fd)
 {
-	static int last_b, rept;
+	static Byte last_b;
+	static int rept;
 
 	switch (mode) {
 	case PCX_NORMAL:
@@ -154,10 +155,10 @@ static int start_PCX(const OUT_PAR * po, const GEN_PAR * pg, FILE * fd)
 		h.bits = 8;	/* Bits per pixel               */
 	h.xmin = 0;		/* Range of bitmap              */
 	h.ymin = 0;
-	h.xmax = po->picbuf->nc - 1;
-	h.ymax = po->picbuf->nr - 1;
-	h.hres = po->dpi_x;	/* Resolution                   */
-	h.vres = po->dpi_y;
+	h.xmax = (short) (po->picbuf->nc - 1);
+	h.ymax = (short) (po->picbuf->nr - 1);
+	h.hres = (short) po->dpi_x;	/* Resolution                   */
+	h.vres = (short) po->dpi_y;
 
 	if (po->picbuf->depth == 1) {
 		h.palette[0][0] = 0;
@@ -219,14 +220,14 @@ static int start_PCX(const OUT_PAR * po, const GEN_PAR * pg, FILE * fd)
 /*  h.planes      = po->picbuf->depth; *//* Number of color planes         */
 	if (po->picbuf->depth == 1) {
 		h.planes = 1;
-		h.byteperline = po->picbuf->nb;
+		h.byteperline = (short) po->picbuf->nb;
 	} else {
-		h.byteperline = 8 * po->picbuf->nb;	/* Number of bytes per line   */
+		h.byteperline = (short) (8 * po->picbuf->nb);	/* Number of bytes per line   */
 		h.planes = 3;
 	}
 	h.paletteinfo = 1;	/* 1 = color & b/w, 2 = gray scale */
-	h.hscreensize = po->picbuf->nc - 1;	/* Horizontal screen size in pixels */
-	h.vscreensize = po->picbuf->nr - 1;	/* Vertical screen size in pixels */
+	h.hscreensize = (short) (po->picbuf->nc - 1);	/* Horizontal screen size in pixels */
+	h.vscreensize = (short) (po->picbuf->nr - 1);	/* Vertical screen size in pixels */
 	for (i = 0; i < 54;) {	/* Filler for a max. of 128 bytes  */
 		h.dummy[i++] = '\0';
 		h.dummy[i++] = '\0';
@@ -356,10 +357,10 @@ int PicBuf_to_PCX(const GEN_PAR * pg, const OUT_PAR * po)
    ** Allocate buffers for temporary conversion
    **/
 	if (po->picbuf->depth > 1) {
-		p_I = calloc(po->picbuf->nb, 8 * sizeof(Byte));
-		p_B = calloc(po->picbuf->nb, 8 * sizeof(Byte));
-		p_G = calloc(po->picbuf->nb, 8 * sizeof(Byte));
-		p_R = calloc(po->picbuf->nb, 8 * sizeof(Byte));
+		p_I = calloc((size_t) (po->picbuf->nb), 8 * sizeof(Byte));
+		p_B = calloc((size_t) (po->picbuf->nb), 8 * sizeof(Byte));
+		p_G = calloc((size_t) (po->picbuf->nb), 8 * sizeof(Byte));
+		p_R = calloc((size_t) (po->picbuf->nb), 8 * sizeof(Byte));
 		if (p_I == NULL || p_B == NULL || p_G == NULL
 		    || p_R == NULL) {
 			Eprintf
@@ -390,9 +391,12 @@ int PicBuf_to_PCX(const GEN_PAR * pg, const OUT_PAR * po)
 				color_index =
 				    index_from_RowBuf(row, x, po->picbuf);
 /*fprintf(stderr,"color_index= %d\n",color_index);   */
-				p_R[x] = 255 - pt.clut[color_index][0];
-				p_G[x] = 255 - pt.clut[color_index][1];
-				p_B[x] = 255 - pt.clut[color_index][2];
+				p_R[x] =
+				    (Byte) (255 - pt.clut[color_index][0]);
+				p_G[x] =
+				    (Byte) (255 - pt.clut[color_index][1]);
+				p_B[x] =
+				    (Byte) (255 - pt.clut[color_index][2]);
 /*
 	p_R[x] = 255-pt.clut(color_index,R) ;
 	p_G[x] = 255-pt.clut(color_index,G) ;
