@@ -1,3 +1,4 @@
+#ifdef HAS_OS2_PM
 /*
    Copyright (c) 1991 - 1994 Heinz W. Werntges.  All rights reserved.
    Distributed by Free Software Foundation, Inc.
@@ -274,3 +275,4 @@ int PicBuf_to_PM(const GEN_PAR * pg, const OUT_PAR * po)
 	win_close();
 	return 0;
 }
+#endif
