@@ -176,8 +176,9 @@ int sy;
 	im->pixels =
 	    (unsigned char **) malloc(sizeof(unsigned char *) * sy);
 	for (i = 0; (i < sy); i++) {
-		im->pixels[i] =
-		    (unsigned char *) calloc(sx, sizeof(unsigned char));
+		im->pixels[i] = (unsigned char *) calloc((size_t) sx,
+							 sizeof(unsigned
+								char));
 	}
 	im->sx = sx;
 	im->sy = sy;
@@ -227,7 +228,7 @@ int b;
 
 void pdImageColorTransparent(im, color)
 pdImagePtr im;
-int color;
+unsigned char color;
 {
 	im->transparent = color;
 }
@@ -236,7 +237,7 @@ void pdImageSetPixel(im, x, y, color)
 pdImagePtr im;
 int x;
 int y;
-int color;
+unsigned char color;
 {
 	if (pdImageBoundsSafe(im, x, y)) {
 		im->pixels[y][x] = color;
