@@ -1,7 +1,7 @@
 /*
    Copyright (c) 1991 - 1994 Heinz W. Werntges.  
    Parts Copyright (c) 1995 Emmanuel Bigler, (c)2002 Michael Rooke,
-   (c) 1999,2001,2002 Martin Kroeker.
+   (c) 1999,2001,2002,2003 Martin Kroeker.
    All rights reserved. Distributed by Free Software Foundation, Inc.
 
 This file is part of HP2xx.
@@ -46,11 +46,17 @@ copies.
  ** 95/03/23  V 1.11  E.B. new mode 6 gnuplot ascii format
  ** 02/..     V 1.12  MK   new modes 7, DXF, and 8, Scalable Vector Graphics
  ** 02/12/20  V 1.13  MJR  new mode 9 to generic CNC G Code
+ ** 03/02/26          MK   Simple HPGL now writes %f instead of %g - 
+ **                        HPGL does not tolerate exponent notation
+ ** 03/02/24          GV   Added figure limits and pen/color mapping to DXF
  **/
 
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <math.h>
+/* needed for floor */
+
 #ifdef ATARI
 #include <string.h>
 #include <ctype.h>
@@ -73,6 +79,8 @@ int to_mftex(const GEN_PAR * pg, const OUT_PAR * po, int mode)
 	FILE *md = NULL;
 	PEN_W pensize;
 	int pencolor, pen_no, chars_out = 0, max_chars_out = 210;
+	int mapped_pen_no;
+	PEN_W mapped_pen_size;	/* for DXF */
 	int toolz = 0;
 	int np = 1, err = 0;
 	char *ftype = "", *scale_cmd = "", *pen_cmd = "",
@@ -156,11 +164,11 @@ int to_mftex(const GEN_PAR * pg, const OUT_PAR * po, int mode)
 		ftype = "Simple HP-GL";
 		scale_cmd = "";
 		pen_cmd = "SP%1d;";
-		poly_start = "PA;PU%g,%g;";
-		poly_next = "PD%g,%g;";
+		poly_start = "PA;PU%f,%f;";
+		poly_next = "PD%f,%f;";
 		poly_last = poly_next;
 		poly_end = "";
-		draw_dot = "PU%g,%g;PD%g,%g;PU;";
+		draw_dot = "PU%f,%f;PD%f,%f;PU;";
 		exit_cmd = "";
 		break;
 	case 6:		/* gnuplot ascii input from HP-GL mode */
@@ -177,11 +185,10 @@ int to_mftex(const GEN_PAR * pg, const OUT_PAR * po, int mode)
 	case 7:		/* DXF */
 		ftype = "DXF";
 		scale_cmd =
-		    "  0\nSECTION\n  2\nHEADER\n  9\n$ACADVER\n  1\nAC1009\n  0\nENDSEC\n  0\nSECTION\n  2\nBLOCKS\n  0\nENDSEC\n  0\nSECTION\n  2\nENTITIES\n  0\n";
-		pen_cmd = "";
-		/*FIXME*/
-		    poly_start =
-		    "LINE\n  8\n0\n 10\n%g\n 20\n%g\n 30\n0.0\n";
+		    "  0\nSECTION\n  2\nHEADER\n 999\nGenerated by hp2xx\n 9\n$ACADVER\n  1\nAC1009\n 9\n$EXTMIN\n 10\n%g\n 20 \n%g\n 9\n$EXTMAX\n 10\n%g\n 20\n%g\n 0\nENDSEC\n  0\nSECTION\n  2\nBLOCKS\n  0\nENDSEC\n  0\nSECTION\n  2\nENTITIES\n  0\n";
+		pen_cmd = "";	/* linecolor attribute (group 62) does this */
+		poly_start =
+		    "LINE\n  8\n0\n 62\n%d\n 39\n%g\n 10\n%g\n 20\n%g\n 30\n0.0\n";
 		poly_next = " 11\n%g\n 21\n%g\n 31\n0.0\n  0\n";
 		poly_last = poly_next;
 		poly_end = "";
@@ -301,7 +308,7 @@ int to_mftex(const GEN_PAR * pg, const OUT_PAR * po, int mode)
 	}
 #endif
 
-	if (pg->is_color)
+	if (pg->is_color && mode < 5)
 		Eprintf("\nWARNING: MF/TeX modes ignore colors!\n");
 
 #ifdef ATARI
@@ -331,7 +338,9 @@ int to_mftex(const GEN_PAR * pg, const OUT_PAR * po, int mode)
 		}
 
 		if (mode == 7)
-			fprintf(md, scale_cmd);
+			fprintf(md, scale_cmd, po->xoff, po->yoff,
+				po->width + po->xoff,
+				po->height + po->yoff);
 		if (mode == 8)
 			fprintf(md, scale_cmd, po->width * 2.834646,
 				po->height * 2.834646);
@@ -374,7 +383,7 @@ int to_mftex(const GEN_PAR * pg, const OUT_PAR * po, int mode)
 		ycoord2mm = po->height / (po->ymax - po->ymin);
 	}
 
-	if (mode == 7 || mode == 8) {
+	if (mode == 8) {
 		xcoord2mm *= 2.834646;
 		ycoord2mm *= 2.834646;
 	}
@@ -405,7 +414,7 @@ int to_mftex(const GEN_PAR * pg, const OUT_PAR * po, int mode)
 					fprintf(md, pen_cmd, pen_no);
 					break;
 				case 8:
-					pencolor = pt.color[pen_no];
+					pencolor = (int) pt.color[pen_no];
 					fprintf(md, pen_cmd,
 						pt.clut[pencolor][0],
 						pt.clut[pencolor][1],
@@ -477,7 +486,7 @@ int to_mftex(const GEN_PAR * pg, const OUT_PAR * po, int mode)
 			break;
 
 		case DRAW_TO:
-			if (mode == 3 || mode == 7) {	/* Needs special treatment: no polygons!        */
+			if (mode == 3) {	/* Needs special treatment: no polygons!        */
 				chars_out = fprintf(md, poly_start,
 						    (pt1.x -
 						     po->xmin) * xcoord2mm,
@@ -493,6 +502,49 @@ int to_mftex(const GEN_PAR * pg, const OUT_PAR * po, int mode)
 						      po->ymin) *
 						     ycoord2mm, np++);
 				break;
+			} else if (mode == 7) {	/* DXF, mapping pen no. or width to color */
+				switch (po->specials) {
+				case 1:	/* pen number is color number           */
+					mapped_pen_no = pen_no;
+					mapped_pen_size = pensize;
+					break;
+				case 2:	/* pen width translates to color number */
+					mapped_pen_no =
+					    (int) floor(pensize * 10.);
+					mapped_pen_size = pensize;
+					if (mapped_pen_no < 1)
+						mapped_pen_no = 1;
+					break;
+				case 3:	/* as above, upper limit at 0.4 == 4 */
+					mapped_pen_no =
+					    (int) floor(pensize * 10.);
+					if (mapped_pen_no < 1)
+						mapped_pen_no = 1;
+					if (mapped_pen_no > 1)
+						mapped_pen_no = 4;
+					mapped_pen_size = pensize;
+					break;
+				default:	/* old behaviour - no mapping */
+					mapped_pen_no = 1;
+					mapped_pen_size = .1;
+				}
+				chars_out = fprintf(md, poly_start,
+						    mapped_pen_no,
+						    mapped_pen_size,
+						    (pt1.x -
+						     po->xmin) * xcoord2mm,
+						    (pt1.y -
+						     po->ymin) * ycoord2mm,
+						    np++);
+				HPGL_Pt_from_tmpfile(&pt1);
+				chars_out += fprintf(md, poly_next,
+						     (pt1.x -
+						      po->xmin) *
+						     xcoord2mm,
+						     (pt1.y -
+						      po->ymin) *
+						     ycoord2mm, np++);
+				break;
 			} else if (mode == 9 && toolz == 0) {	/* Tool still up!  */
 				chars_out =
 				    fprintf(md,
