@@ -157,17 +157,18 @@ win_open(const GEN_PAR * pg, char *title, int x, int y, int w, int h)
 	WinAttr.background_pixel = WhitePixel(XDisplay, XScreen);
 	WinAttr.border_pixel = WhitePixel(XDisplay, XScreen);
 	WinAttr.backing_store = Always;
-	ValueMask = CWBackPixel | CWBorderPixel | CWBackingStore;
+	ValueMask =
+	    (unsigned long) (CWBackPixel | CWBorderPixel | CWBackingStore);
 
 	/**
 	 ** Create Window
 	 **/
 
 	XWin = XCreateWindow(XDisplay, XRoot,
-			     x, y, w, h,
+			     x, y, (unsigned int) w, (unsigned int) h,
 			     1, 0,
-			     CopyFromParent, CopyFromParent, ValueMask,
-			     &WinAttr);
+			     CopyFromParent, (Visual *) CopyFromParent,
+			     ValueMask, &WinAttr);
 
 	/**
 	 ** Define window properties
@@ -396,7 +397,8 @@ int PicBuf_to_X11(const GEN_PAR * pg, OUT_PAR * po)
 					       WhitePixel(XDisplay,
 							  XScreen));
 				XFillRectangle(XDisplay, XWin, XGcWin, 0,
-					       0, scr_width, scr_height);
+					       0, (unsigned int) scr_width,
+					       (unsigned int) scr_height);
 				goto REDRAW;	/* yes, goto in C is ugly */
 			}
 			if (WaitEvent.xbutton.button == Button2) {
@@ -404,7 +406,8 @@ int PicBuf_to_X11(const GEN_PAR * pg, OUT_PAR * po)
 					       WhitePixel(XDisplay,
 							  XScreen));
 				XFillRectangle(XDisplay, XWin, XGcWin, 0,
-					       0, scr_width, scr_height);
+					       0, (unsigned int) scr_width,
+					       (unsigned int) scr_height);
 				goto REDRAW;	/* yes, goto in C is ugly */
 			}
 			break;
